# fed_net_liquidity.py

Library for calculating Fed Net Liquidity

    Fed Net Liquidity = WALCL - RRP - TGA

Where:

    WALCL = Federal Reserve balance sheet assets

pypi package:

https://pypi.org/project/fed-net-liquidity/